@@ -34,8 +34,8 @@ def add_tasks_and_process_time_middleware(new_app):
         g.request = request
         g.app = new_app
         print("url path", request.url.path, "***url", request.url)
-        if 'aws.context' in request.scope:
-            context = request.scope['aws.context']
+        if "aws.context" in request.scope:
+            context = request.scope["aws.context"]
             context.serverless_sdk.set_endpoint(request.url.path)
         response = await call_next(request)
         if response.status_code == 404 and g.settings.save_calls:
@@ -105,7 +105,7 @@ def create_handler(app):
         """Handler to give to lambda... which wraps FastAPI"""
         if event.get("source") in ["aws.events", "serverless-plugin-warmup"]:
             print("Lambda is warm, now!!!")
-            context.serverless_sdk.set_endpoint('/warmup')
+            context.serverless_sdk.set_endpoint("/warmup")
             return {}
 
         asgi_handler = Mangum(app, api_gateway_base_path=g.settings.stage)
